import java.awt.*;
import java.awt.image.*;
import java.io.*;
import javax.imageio.*;
import javax.swing.*;
import javax.swing.text.*;

/**
 * Eigenes Grafik-Panel
 * 
 * @author Toens
 * @version v0.1
 */
public class JGrafikPanel extends JPanel {
    int frameNr;
    
    // Kann für animaitionen genutzt werden. Beim Aufruf dieser Methode wird die
    // Eigenschaft frameNr um eins erhöht...
    public void nextFrame() {
        // frameNr hochzaehlen, aber wenn 100, dann wieder bei 0 beginnen
        frameNr = frameNr + 1;
        frameNr = frameNr % 100;
    }
    

    /**
     * Kernstueck des JGrafikPanels: paintComponent ist eine Methode, die
     * eigentlich von der Oberklasse JPanel stammt (unser JGrafikPanel erbt
     * ja von der JPanel-Klasse). Hier wird die Methode ueberschrieben.
     * Wir sorgen hier naemlich dafuer, dass unsere eigenen Inhalte dort
     * hineingezeichnet werden. Die Methode wird immer dann vom Fenstersystem
     * (bzw. indirekt vom Windows-Betriebssystem) aufgerufen, wenn der Inhalt
     * neu gezeichnet werden soll.
     */
    public void paintComponent(Graphics g) {
        Graphics2D g2 = (Graphics2D)g;
        g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING,
            RenderingHints.VALUE_ANTIALIAS_ON);
        g2.setRenderingHint(RenderingHints.KEY_INTERPOLATION,
            RenderingHints.VALUE_INTERPOLATION_BILINEAR);

        super.paintComponent(g); // Zur Sicherheit die urspruengliche Methoder der Oberklasse aufrufen

        Rectangle r = this.getBounds(null);
        int h = r.height; // Höhe
        int w = r.width;  // Breite

        // Hintergrund in Grau füllen
        g.setColor(Color.gray);
        g.fillRect(0,0,w,h);

        // genauere Dokumentation der Zeichen-Methoden: siehe
        // https://docs.oracle.com/javase/7/docs/api/java/awt/Graphics.html
        
        // Ein Blauer Kreis...
        g.setColor(Color.blue);
        g.drawOval(80,50+frameNr,20,20);
       
        
        // Ein grünes Dreieck
        g.setColor(Color.green);
        int[] xk = new int[3];
        int[] yk = new int[3];
        xk[0] = 50; yk[0] = 20;
        xk[1] = 20; yk[1] = 120;
        xk[2] = 80; yk[2] = 120;
        g.fillPolygon(xk,yk,3);
        
        // Ein pinkes Rechteck
        g.setColor(Color.pink);
        g.drawRect(150,10+frameNr,100,40);
        
        // Ein blaues, ausgefülltes Rechteck
        g.setColor(Color.blue);
        g.fillRect(200,20,100,40);
        
        // Ein weißer Text
        g.setColor(Color.white);
        g.drawString("Hallo",10+frameNr,40);
        
        // ein gelber, ausgefüllter Kreis
        g.setColor(Color.yellow);
        g.fillOval(90,90,20,20);

        // ein springender Ball
        g.setColor(Color.orange);
        int ballYWert = (int) ((-1) * (frameNr * (frameNr-100) * (200.0/2500)));
        g.fillOval(190, 200 - ballYWert, 20, 20);
        
    }
}
